/**
 * \filed core/msrun.cpp
 * \date 5/4/2017
 * \author Olivier Langella
 * \brief describes an MS run (chemical sample injected in a mass spectrometer)
 */


/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <Olivier.Langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <Olivier.Langella@u-psud.fr> - initial API and implementation
******************************************************************************/


#include "msrun.h"
#include <QFileInfo>

MsRun::MsRun(const QString & location):pappso::MsRunId(location) {
    QFileInfo fileinfo(location);
}

MsRun::MsRun(const MsRun& other):pappso::MsRunId(other) {
    _param_stats = other._param_stats;
}

MsRun::~MsRun() {
}

void MsRun::setMsRunStatistics(MsRunStatistics param, const QVariant& value) {
    _param_stats.insert(std::pair<MsRunStatistics, QVariant>(param, value));
}

const std::map<MsRunStatistics, QVariant> & MsRun::getMsRunStatisticsMap() const {
    return _param_stats;
}

const QVariant MsRun::getMsRunStatistics(MsRunStatistics param) const {
    try {
        return _param_stats.at(param);
    }
    catch (std::out_of_range) {
        return QVariant();
    }
}
